@@ -1,4 +1,5 @@
 context("ms_clip_erase")
+library(geojsonlint)
 suppressPackageStartupMessages(library(geojsonio, quietly = TRUE))
 
 poly <- structure("{\"type\":\"FeatureCollection\",\"features\":[{\"type\":\"Feature\",\"properties\":{},\"geometry\":{\"type\":\"Polygon\",\"coordinates\":[[[52.8658,-44.7219],[53.7702,-40.4873],[55.3204,-37.5579],[56.2757,-37.917],[56.184,-40.6443],[61.0835,-40.7529],[58.0202,-43.634],[61.6699,-45.0678],[62.737,-46.2841],[55.7763,-46.2637],[54.9742,-49.1184],[52.799,-45.9386],[52.0329,-49.5677],[50.1747,-52.1814],[49.0098,-52.3641],[52.7068,-45.7639],[43.2278,-47.1908],[48.4755,-45.1388],[50.327,-43.5207],[48.0804,-41.2784],[49.6307,-40.6159],[52.8658,-44.7219]]]}}]}", class = c("json", "geo_json"))
@@ -44,7 +45,7 @@ test_that("ms_clip.geo_json works", {
   expect_is(default_clip_json, "geo_json")
   expect_equal(default_clip_json, structure("{\"type\":\"FeatureCollection\",\"features\":[\n{\"type\":\"Feature\",\"geometry\":{\"type\":\"Polygon\",\"coordinates\":[[[52.8658,-44.7219],[53.7702,-40.4873],[54.02807275892674,-40],[55,-40],[55,-45],[51,-45],[51,-42.353820249760446],[52.8658,-44.7219]]]},\"properties\":{\"rmapshaperid\":0}}\n]}", class = c("json",
                                                                                                                                                                                                                                                                                                                                                                      "geo_json")))
-  expect_equal(geojsonio::lint(default_clip_json), "valid")
+  expect_true(geojsonlint::geojson_validate(default_clip_json))
 })
 
 test_that("ms_clip.character works", {
@@ -53,7 +54,7 @@ test_that("ms_clip.character works", {
   expect_is(default_clip_json, "geo_json")
   expect_equal(default_clip_json, structure("{\"type\":\"FeatureCollection\",\"features\":[\n{\"type\":\"Feature\",\"geometry\":{\"type\":\"Polygon\",\"coordinates\":[[[52.8658,-44.7219],[53.7702,-40.4873],[54.02807275892674,-40],[55,-40],[55,-45],[51,-45],[51,-42.353820249760446],[52.8658,-44.7219]]]},\"properties\":{\"rmapshaperid\":0}}\n]}", class = c("json",
                                                                                                                                                                                                                                                                                                                                                                      "geo_json")))
-  expect_equal(geojsonio::lint(default_clip_json), "valid")
+  expect_true(geojsonlint::geojson_validate(default_clip_json))
 })
 
 test_that("ms_erase.geo_json works", {
@@ -62,7 +63,7 @@ test_that("ms_erase.geo_json works", {
   expect_is(default_erase_json, "geo_json")
   expect_equal(default_erase_json, structure("{\"type\":\"FeatureCollection\",\"features\":[\n{\"type\":\"Feature\",\"geometry\":{\"type\":\"Polygon\",\"coordinates\":[[[54.02807275892674,-40],[55.3204,-37.5579],[56.2757,-37.917],[56.184,-40.6443],[61.0835,-40.7529],[58.0202,-43.634],[61.6699,-45.0678],[62.737,-46.2841],[55.7763,-46.2637],[54.9742,-49.1184],[52.799,-45.9386],[52.0329,-49.5677],[50.1747,-52.1814],[49.0098,-52.3641],[52.7068,-45.7639],[43.2278,-47.1908],[48.4755,-45.1388],[50.327,-43.5207],[48.0804,-41.2784],[49.6307,-40.6159],[51,-42.353820249760446],[51,-45],[55,-45],[55,-40],[54.02807275892674,-40]]]},\"properties\":{\"rmapshaperid\":0}}\n]}", class = c("json",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         "geo_json")))
-  expect_equal(geojsonio::lint(default_erase_json), "valid")
+  expect_true(geojsonlint::geojson_validate(default_erase_json))
 })
 
 test_that("ms_erase.character works", {
@@ -71,7 +72,7 @@ test_that("ms_erase.character works", {
   expect_is(default_erase_json, "geo_json")
   expect_equal(default_erase_json, structure("{\"type\":\"FeatureCollection\",\"features\":[\n{\"type\":\"Feature\",\"geometry\":{\"type\":\"Polygon\",\"coordinates\":[[[54.02807275892674,-40],[55.3204,-37.5579],[56.2757,-37.917],[56.184,-40.6443],[61.0835,-40.7529],[58.0202,-43.634],[61.6699,-45.0678],[62.737,-46.2841],[55.7763,-46.2637],[54.9742,-49.1184],[52.799,-45.9386],[52.0329,-49.5677],[50.1747,-52.1814],[49.0098,-52.3641],[52.7068,-45.7639],[43.2278,-47.1908],[48.4755,-45.1388],[50.327,-43.5207],[48.0804,-41.2784],[49.6307,-40.6159],[51,-42.353820249760446],[51,-45],[55,-45],[55,-40],[54.02807275892674,-40]]]},\"properties\":{\"rmapshaperid\":0}}\n]}", class = c("json",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         "geo_json")))
-  expect_equal(geojsonio::lint(default_erase_json), "valid")
+  expect_true(geojsonlint::geojson_validate(default_erase_json))
 })
 
 ## Spatial Classes
