@@ -21,7 +21,7 @@ test_that("ms_explode.geo_json works", {
 })
 
 test_that("ms_explode.geo_json errors correctly", {
-  expect_error(ms_explode("foo"), "Input is not valid geojson")
+  expect_error(ms_explode('{foo: "bar"}'), "Input is not valid geojson")
 })
 
 test_that("ms_explode.character works", {
@@ -81,4 +81,4 @@ test_that("ms_explode works with points", {
   expect_equal(ms_explode(multi_point), multi_point_exploded)
   expect_equal(ms_explode(geojson_list(multi_point)), geojson_list(multi_point_exploded))
   # expect_is(ms_explode(geojsonio::geojson_sp(multi_point)), spatialPointsDataFrame)
-})
\ No newline at end of file
+})
